@@ -1,12 +1,12 @@
 package HTML::Latemp::GenMakeHelpers;
-$HTML::Latemp::GenMakeHelpers::VERSION = '0.10.1';
+$HTML::Latemp::GenMakeHelpers::VERSION = '0.12.0';
 use strict;
 use warnings;
 use autodie;
 use 5.014;
 
 package HTML::Latemp::GenMakeHelpers::Base;
-$HTML::Latemp::GenMakeHelpers::Base::VERSION = '0.10.1';
+$HTML::Latemp::GenMakeHelpers::Base::VERSION = '0.12.0';
 sub new
 {
     my $class = shift;
@@ -17,7 +17,7 @@ sub new
 }
 
 package HTML::Latemp::GenMakeHelpers::HostEntry;
-$HTML::Latemp::GenMakeHelpers::HostEntry::VERSION = '0.10.1';
+$HTML::Latemp::GenMakeHelpers::HostEntry::VERSION = '0.12.0';
 our @ISA = (qw(HTML::Latemp::GenMakeHelpers::Base));
 
 use Class::XSAccessor accessors =>
@@ -34,11 +34,11 @@ sub initialize
 }
 
 package HTML::Latemp::GenMakeHelpers::Error;
-$HTML::Latemp::GenMakeHelpers::Error::VERSION = '0.10.1';
+$HTML::Latemp::GenMakeHelpers::Error::VERSION = '0.12.0';
 our @ISA = (qw(HTML::Latemp::GenMakeHelpers::Base));
 
 package HTML::Latemp::GenMakeHelpers::Error::UncategorizedFile;
-$HTML::Latemp::GenMakeHelpers::Error::UncategorizedFile::VERSION = '0.10.1';
+$HTML::Latemp::GenMakeHelpers::Error::UncategorizedFile::VERSION = '0.12.0';
 our @ISA = (qw(HTML::Latemp::GenMakeHelpers::Error));
 
 use Class::XSAccessor accessors => { 'file' => 'file', 'host' => 'host', };
@@ -60,7 +60,7 @@ package HTML::Latemp::GenMakeHelpers;
 our @ISA = (qw(HTML::Latemp::GenMakeHelpers::Base));
 
 use File::Find::Rule ();
-use File::Basename qw/ basename /;
+use File::Basename   qw/ basename /;
 
 use Class::XSAccessor accessors => {
     '_common_buckets'             => '_common_buckets',
@@ -381,34 +381,34 @@ X8X_COMMON_DOCS_DEST := \$(patsubst %,\$(X8X_DEST)/%,\$(COMMON_DOCS))
 X8X_TARGETS := \$(X8X_DEST) \$(X8X_DIRS_DEST) \$(X8X_COMMON_DIRS_DEST) \$(X8X_COMMON_IMAGES_DEST) \$(X8X_COMMON_DOCS_DEST) \$(X8X_COMMON_TTMLS_DEST) \$(X8X_IMAGES_DEST) \$(X8X_DOCS_DEST) \$(X8X_TTMLS_DEST)
 
 \$(X8X_DOCS_DEST) : $h_dest_star : \$(X8X_SRC_DIR)/%${out_docs_ext} \$(DOCS_COMMON_DEPS)
-	$no_common_cmd
+\t$no_common_cmd
 
 \$(X8X_TTMLS_DEST) : $h_dest_star : \$(X8X_SRC_DIR)/%.ttml \$(TTMLS_COMMON_DEPS)
-	ttml -o \$@ \$(X8X_TTML_FLAGS) -DLATEMP_FILENAME=\$(patsubst $h_dest_star,%,\$(patsubst %.ttml,%,\$@)) \$<
+\tttml -o \$@ \$(X8X_TTML_FLAGS) -DLATEMP_FILENAME=\$(patsubst $h_dest_star,%,\$(patsubst %.ttml,%,\$@)) \$<
 
 \$(X8X_DIRS_DEST) : $h_dest_star :
-	mkdir -p \$@
-	touch \$@
+\tmkdir -p \$@
+\ttouch \$@
 
 \$(X8X_IMAGES_DEST) : $nci_h_dest_star : \$(X8X_SRC_DIR)/%
-	\$(call LATEMP_COPY)
+\t\$(call LATEMP_COPY)
 
 \$(X8X_COMMON_IMAGES_DEST) : $ci_h_dest_star : \$(COMMON_SRC_DIR)/%
-	\$(call LATEMP_COPY)
+\t\$(call LATEMP_COPY)
 
 \$(X8X_COMMON_TTMLS_DEST) : $h_dest_star : \$(COMMON_SRC_DIR)/%.ttml \$(TTMLS_COMMON_DEPS)
-	ttml -o \$@ \$(X8X_TTML_FLAGS) -DLATEMP_FILENAME=\$(patsubst $h_dest_star,%,\$(patsubst %.ttml,%,\$@)) \$<
+\tttml -o \$@ \$(X8X_TTML_FLAGS) -DLATEMP_FILENAME=\$(patsubst $h_dest_star,%,\$(patsubst %.ttml,%,\$@)) \$<
 
 \$(X8X_COMMON_DOCS_DEST) : $h_dest_star : \$(COMMON_SRC_DIR)/%${out_docs_ext} \$(DOCS_COMMON_DEPS)
-	$common_cmd
+\t$common_cmd
 
 \$(X8X_COMMON_DIRS_DEST)  : $h_dest_star :
-	mkdir -p \$@
-	touch \$@
+\tmkdir -p \$@
+\ttouch \$@
 
 \$(X8X_DEST):
-	mkdir -p \$@
-	touch \$@
+\tmkdir -p \$@
+\ttouch \$@
 EOF
 }
 
@@ -482,7 +482,7 @@ HTML::Latemp::GenMakeHelpers - A Latemp Utility Module.
 
 =head1 VERSION
 
-version 0.10.1
+version 0.12.0
 
 =head1 SYNOPSIS
 
@@ -502,7 +502,27 @@ version 0.10.1
 
 =head1 VERSION
 
-version 0.10.1
+version 0.12.0
+
+=head1 DEPRECATION NOTE
+
+The use of L<HTML::Latemp::GenMakeHelpers> is now discouraged given it seems
+that for most use cases, it is easier and often even requires less code, to
+use L<File::Find::Object> or similar directly.
+
+L<HTML::Latemp::GenMakeHelpers> will continue to be maintained and bugs
+and build/test failures will hopefully be investigated and fixed, but it
+is hereby B<deprecated>.
+
+For some examples, see:
+
+=over 4
+
+=item * L<https://github.com/shlomif/perl-begin/blob/ad8c054a1301e4fb16772561bacaf4d0d2e36588/gen-helpers#L62>
+
+=item * L<https://github.com/shlomif/shlomi-fish-homepage/blob/ef5619d08b71ae1b804f132a19e8e9a8ec09e354/bin/gen-helpers-main.pl#L153>
+
+=back
 
 =head1 API METHODS
 
@@ -590,23 +610,8 @@ Process the host $host.
 
 Shlomi Fish, L<http://www.shlomifish.org/> .
 
-=head1 BUGS
-
-Please report any bugs or feature requests to
-C<bug-html-latemp-genmakehelpers@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=HTML-Latemp-GenMakeHelpers>.
-I will be notified, and then you'll automatically be notified of progress on
-your bug as I make changes.
-
 =head1 ACKNOWLEDGEMENTS
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2005 Shlomi Fish, All Rights Reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the MIT X11 License.
-
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
@@ -628,14 +633,6 @@ L<https://metacpan.org/release/HTML-Latemp-GenMakeHelpers>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/HTML-Latemp-GenMakeHelpers>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -644,14 +641,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=HTML-Latemp-GenMakeHelpers>
 
 =item *
 
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/HTML-Latemp-GenMakeHelpers>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -744,14 +733,6 @@ L<https://metacpan.org/release/HTML-Latemp-GenMakeHelpers>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/HTML-Latemp-GenMakeHelpers>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -760,14 +741,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=HTML-Latemp-GenMakeHelpers>
 
 =item *
 
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/HTML-Latemp-GenMakeHelpers>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
